==> crm-commom-vo-1.0.8.release.jar: com/biz/crm/nebular/mdm/tableconfig/MdmTableConfigRespVo.java <==
package com.biz.crm.nebular.mdm.tableconfig;
import com.biz.crm.nebular.mdm.CrmExtTenVo;
import com.biz.crm.nebular.mdm.pageconfig.MdmColumnConfigRespVo;
import io.swagger.annotations.ApiModel;
import lombok.Data;
import io.swagger.annotations.ApiModelProperty;
import com.fasterxml.jackson.annotation.JsonFormat;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 页面配置返回vo
 *
 * @author zxw
 * @date 2020-11-21 14:25:32
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "页面配置")
@SaturnEntity(name = "MdmTableConfigRespVo", description = "页面配置")
public class MdmTableConfigRespVo extends CrmExtTenVo {

    @ApiModelProperty("菜单编码")
    @SaturnColumn(description = "菜单编码")
    private String functionCode;

    @ApiModelProperty("是否有边框1是0否")
    @SaturnColumn(description = "是否有边框1是0否")
    private Boolean border;

    @ApiModelProperty("是否允许拖动列宽 是否允许拖动列宽1是0否")
    @SaturnColumn(description = "是否允许拖动列宽 是否允许拖动列宽1是0否")
    private Boolean resizable;

    @ApiModelProperty("标签名称")
    @SaturnColumn(description = "标签名称")
    private String showHeader;

    @ApiModelProperty("默认显示")
    @SaturnColumn(description = "默认显示")
    private String emptyText;

    @ApiModelProperty("宽度")
    @SaturnColumn(description = "宽度")
    private String width;

    @ApiModelProperty("对齐方式")
    @SaturnColumn(description = "对齐方式")
    private String align;

    @ApiModelProperty("选中行")
    @SaturnColumn(description = "选中行")
    private Boolean highlightHoveRow;

    @ApiModelProperty(" 是否展示省略号")
    @SaturnColumn(description = " 是否展示省略号")
    private Boolean showOverflow;

    @ApiModelProperty("高度")
    @SaturnColumn(description = "高度")
    private String height;

    @ApiModelProperty("是否保持原始值状态")
    @SaturnColumn(description = "是否保持原始值状态")
    private Boolean keepSource;

    @ApiModelProperty("列配置集合")
    private List<MdmColumnConfigRespVo> column;

    @ApiModelProperty("编辑配置")
    private String editConfig;

    private String treeConfig;

    @ApiModelProperty("搜索框配置")
    private String formConfig;

    @ApiModelProperty("后台请求地址")
    private String url;

}

==> crm-commom-vo-1.1.7.1.release.jar: com/biz/crm/nebular/mdm/tableconfig/MdmTableConfigRespVo.java <==
package com.biz.crm.nebular.mdm.tableconfig;
import com.biz.crm.nebular.mdm.CrmExtTenVo;
import com.biz.crm.nebular.mdm.button.MdmButtonReqVo;
import com.biz.crm.nebular.mdm.button.MdmButtonRespVo;
import com.biz.crm.nebular.mdm.pageconfig.MdmColumnConfigRespVo;
import io.swagger.annotations.ApiModel;
import lombok.Data;
import io.swagger.annotations.ApiModelProperty;
import com.fasterxml.jackson.annotation.JsonFormat;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 页面配置返回vo
 *
 * @author zxw
 * @date 2020-11-21 14:25:32
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "页面配置")
@SaturnEntity(name = "MdmTableConfigRespVo", description = "页面配置")
public class MdmTableConfigRespVo extends CrmExtTenVo {

    @ApiModelProperty("菜单编码")
    @SaturnColumn(description = "菜单编码")
    private String functionCode;

    @ApiModelProperty("是否有边框1是0否")
    @SaturnColumn(description = "是否有边框1是0否")
    private Boolean border;

    @ApiModelProperty("是否允许拖动列宽 是否允许拖动列宽1是0否")
    @SaturnColumn(description = "是否允许拖动列宽 是否允许拖动列宽1是0否")
    private Boolean resizable;

    @ApiModelProperty("标签名称")
    @SaturnColumn(description = "标签名称")
    private String showHeader;

    @ApiModelProperty("默认显示")
    @SaturnColumn(description = "默认显示")
    private String emptyText;

    @ApiModelProperty("宽度")
    @SaturnColumn(description = "宽度")
    private String width;

    @ApiModelProperty("对齐方式")
    @SaturnColumn(description = "对齐方式")
    private String align;

    @ApiModelProperty("选中行")
    @SaturnColumn(description = "选中行")
    private Boolean highlightHoveRow;

    @ApiModelProperty(" 是否展示省略号")
    @SaturnColumn(description = " 是否展示省略号")
    private Boolean showOverflow;

    @ApiModelProperty("高度")
    @SaturnColumn(description = "高度")
    private String height;

    @ApiModelProperty("是否保持原始值状态")
    @SaturnColumn(description = "是否保持原始值状态")
    private Boolean keepSource;

    @ApiModelProperty("列配置集合")
    private List<MdmColumnConfigRespVo> column;

    @ApiModelProperty("编辑配置")
    private String editConfig;

    private String treeConfig;

    @ApiModelProperty("搜索框配置")
    private String formConfig;

    @ApiModelProperty("后台请求地址")
    private String url;

    @ApiModelProperty("按钮数组")
    private List<MdmButtonRespVo> buttonVos;

}
